#!/usr/bin/env node

const { Command } = require("commander");
const fs = require("fs-extra");
const path = require("path");

const program = new Command();

program
  .version("2.0.4")
  .description("CLI tool to create NodeMongoDBProjectStructure")
  .argument("<destination>", "destination folder")
  .action((destination) => {
    const sourcePath = path.join(__dirname, "NodeMongoDBProjectStructure");
    const destPath = path.resolve(destination);

    fs.copy(sourcePath, destPath, (err) => {
      if (err) {
        console.error("Error copying files:", err);
      } else {
        console.log("Project structure setup successful!\n");
        console.log("Next steps:");
        console.log("1. Navigate to your project directory:");
        console.log(`   cd ${destination}\n`);
        console.log("2. Install the dependencies:");
        console.log("   npm install\n");
        console.log("or install each dependency manually for latest version:");
        console.log("   npm install express mongoose cors dotenv morgan\n");
        console.log("3. Start the development server:");
        console.log("   npm run dev");
        console.log(
          "\nFor more information, check out the README.md file included in the project."
        );
      }
    });
  });

program.parse(process.argv);
